// Ozone
//
// #include "http://byvac.com/mBlib/flb/Library/2016/lib_lcd4.bas"
// #include "http://www.byvac.com/mBlib/flb/Library/2016/lib_wifi.bas"
//
constant BASERATE$ "GBP"
constant RATES$ "EURUSDAUDCZK"
dim timer

//
// *****************************************************************************
// 12 = off
// 13 = on BLOCK
// 14 = on NORMAL
// *****************************************************************************
function lcd.cursor(n)
    lcd_cmd(n)
endf

// *****************************************************************************
// hardware initialise
// *****************************************************************************
function oz.init()
    // lcd parameters for library 4
    lcd.params(0) = ?RA0(0) // RS
    lcd.params(1) = ?RA1(0) // E
    lcd.params(2) = ?RA4(0)  // BL
    lcd.params(3) = ?RB0(0)  // D4
    lcd.params(4) = ?RB1(0)  // D5
    lcd.params(5) = ?RB2(0)  // D6
    lcd.params(6) = ?RB3(0)  // D7
    lcd.init()
    lcd.cursor(12) // off
    wifi.start(*BV507(),2)
    lcd.scrollInit(3,20,150)
endf

// *****************************************************************************
// basn is base currency, eg "GBP"
// returns full list
// *****************************************************************************
function get_rates(basen$,*rv$)
dim req$[80]="/latest?base="+basen$
dim r=0
    rv$=""
    if wifi.sendGetRequest("api.fixer.io",req$,80,"base") = 1 then
        wait(1000)
        com.get1(*rv$)
        r = 1
    else
        print "\r\nError requesting rates"
        com.mopup(100)
    endif
    return r
endf

// *****************************************************************************
// updates display with current data and time
// Mon, 22 Aug 2016 nn:nn:nn
// *****************************************************************************
function oz.update()
dim date$[80]
    date$ = wifi.dt$()
    if strlen(date$) > 10 then
        lcd.cls()
        wait(200)
        lcd.puts(mid$(date$,0,16))
        lcd.rc(1,0)
        lcd.puts(mid$(date$,17,-1))
        lcd.rc(2,0)
        lcd.puts("Base: "+BASERATE$)
    endif
endf

// *****************************************************************************
// returns a list of rates from the currencies set in DISPLAY$
// 1 on sucess
// *****************************************************************************
function oz.getr(*rv$)
dim allrates$[512],p,r$
dim maxlen,count = 0
    rv$=""
    if get_rates(BASERATE$,*allrates$) then
        maxlen = strlen(RATES$)
        while count <> maxlen
            r$ = mid$(RATES$,count,3)
            p = pos(allrates$,r$)
            if p > 0 then
                rv$ = rv$+r$+":"+mid$(allrates$,p+5,6)+"   "
            endif
            count = count + 3
        wend
        return 1
    endif
    return 0
endf

// *****************************************************************************
// updates display with current date and time
// has some checks so user knows whats going on
// *****************************************************************************
function oz.doup()
dim a$[256]
    if wifi.check() <> 1 then
        lcd.cls()
        lcd.puts("Loss of WiFi will  ")
        lcd.rc(1,0)
        lcd.puts("try again later")
        return
    endif

    oz.update()
    if oz.getr(*a$) = 1 then
        lcd.scrollText(a$)
    else
        lcd.cls()
        lcd.puts("Loss of WiFi will  ")
        lcd.rc(1,0)
        lcd.puts("try again later")
    endif
endf

// *****************************************************************************
// called by a task every seconds so a count down can be made to next
// pull of exchange rates
// *****************************************************************************
function oz.loop()
dim x = 60 - timer
    timer = timer + 1
    if timer > 60 then
        oz.doup()
        timer = 0
    else
        lcd.rc(2,15)
        lcd.puts("  ")
        lcd.rc(2,15)
        lcd.puts(x)
    endif
endf


function main()
    oz.init()
    wait(500)
    oz.doup()
    timer = 0
    taskadd("oz.loop()",5,1000,1)
endf







